Standard actions
================

This is the full overview of pre-defined standard actions, available in the
:mod:`parce.action` module namespace.

The bundled language definitions use these, and the bundled CSS themes provide
styling for these. But you are free to add your own definitions and use your
own CSS files (which may ``@import`` other CSS files).

See for more information the :mod:`~parce.standardaction` module.


.. literalinclude:: ../../parce/action.py
   :start-after: BEGIN_ACTIONS
   :end-before: END_ACTIONS
